argus_plugins.cases package — Argus-Toolbelt 1.0 documentation

# argus_plugins.cases package

## Submodules

## argus_plugins.cases.remind module

`argus_plugins.cases.remind.` `create_emails`(subject: str, message: str, parsed_cases: dict, notify: list) → dict

  Crates emails from the parsed_cases dict

  Return type: | `dict`
  Parameters: | subject (`str`) – The subject of the email message (`str`) – The boilerplate part of the email parsed_cases (`dict`) – The parsed cases to create emails from notify (`list`) – Who to notify for unassigned cases
  Returns: | A mail for each user

`argus_plugins.cases.remind.` `parse_data`(cases: list, skipable: list) → dict

  Parses cases and associates them with a user

  Return type: | `dict`
  Parameters: | cases (`list`) – Cases to parse skipable (`list`) – If any types of cases are skipable
  Returns: | All cases sorted after the user to send to

`argus_plugins.cases.remind.` `remind`()

  A command for reminding people when they have pending cases that haven’t been updated for a while.

  Parameters: | subject (`str`) – The subject of the email message (`str`) – The body of the email notify (`list`) – Email(s) to notify for unassigned cases service_type (list) – The service type of the case status (list) – The status of the case customer – Customers to use (shortname) priority (list) – Priorities to have on the case skip (list) – Certain things to not notify about days – Amount of days since last activity dry (`bool`) – Runs the program without sending the actual email smtp_host (`str`) – The SMTP host to send mail from
  Alias smtp_host:
  | smtp

## argus_plugins.cases.utils module

This is a helper module for all things case related

## Module contents